==> 2.5.0.zip: cloudlog/application/language/bulgarian/general_words_lang.php <==
<?php

defined('BASEPATH') OR exit('Не е разрешен директен достъп до скрипта');

$lang['error_no_active_station_profile'] = 'Внимание: трябва да зададете местоположение на активната станция.';

$lang['notice_turn_the_radio_on'] = 'Днес не сте правили QSO; време е да включите радиото!';

$lang['general_word_important'] = 'Важно';
$lang['general_word_warning'] = 'Warning';
$lang['general_word_danger'] = 'DANGER';
$lang['general_word_maintenance'] = 'Maintenance';
$lang['general_word_info'] = 'Инфо';
$lang['general_word_choose_file'] = 'Изберете файл';
$lang['general_word_next'] = 'Next';
$lang['general_word_previous'] = 'Previous';
$lang['general_word_cancel'] = "Cancel";
$lang['general_word_ok'] = "OK";
$lang['general_word_attention'] = "Attention";
$lang['general_word_enabled'] = "Enabled";
$lang['general_word_disabled'] = "Disabled";
$lang['general_word_export'] = "Export";
$lang['general_word_import'] = "Import";

$lang['general_word_date'] = 'Дата';
$lang['general_word_time'] = 'Час';
$lang['general_word_time_on'] = 'Time on';
$lang['general_word_time_off'] = 'Time off';
$lang['general_word_datetime'] = 'Дата/Час';
$lang['general_word_none'] = 'Нито едно';
$lang['general_word_name'] = 'Име';
$lang['general_word_location'] = 'Местоположение';
$lang['general_word_comment'] = 'Коментар';
$lang['general_word_general'] = 'Общи';
$lang['general_word_satellite'] = 'Сателит';
$lang['general_word_satellite_short'] = 'Сат';
$lang['general_word_notes'] = 'Бележки';
$lang['general_word_country'] = 'Държава';
$lang['general_word_city'] = 'Град';

$lang['general_word_total'] = 'Общо';
$lang['general_word_year'] = 'Година';
$lang['general_word_month'] = 'Месец';

$lang['general_word_colors'] = "Colors";
$lang['general_word_light'] = "Light/Laser";
$lang['general_word_worked'] = 'Работени';
$lang['general_word_worked_not_confirmed'] = "Worked not confirmed";
$lang['general_word_not_worked'] = "Not worked";
$lang['general_word_confirmed'] = 'Потвърдени';
$lang['general_word_needed'] = 'Необходими';

$lang['general_word_all'] = 'All';
$lang['general_word_no'] = 'Не';
$lang['general_word_yes'] = 'Да';
$lang['general_word_method'] = 'Метод';

$lang['general_word_sent'] = 'Изпратени';
$lang['general_word_received'] = 'Получени';
$lang['general_word_requested'] = 'Заявени';
$lang['general_word_queued'] = 'Queued';
$lang['general_word_table'] = "Table";
$lang['general_word_invalid_ignore'] = 'Invalid (Ignore)';
$lang['general_word_qslcard'] = 'QSL катичка';
$lang['general_word_qslcard_management'] = 'Управление на QSL';
$lang['general_word_qslcards'] = 'QSL картички';
$lang['general_word_qslcard_direct'] = 'Директено';
$lang['general_word_qslcard_bureau'] = 'Бюро';
$lang['general_word_qslcard_electronic'] = 'Electronic';
$lang['general_word_qslcard_manager'] = 'Manager';
$lang['general_word_qslcard_via'] = 'Чрез';
$lang['general_word_eqslcard'] = 'eQSL Card';
$lang['general_word_eqslcards'] = 'eQSL Cards';
$lang['general_word_lotw'] = 'Logbook of the World';
$lang['general_word_lotw_short'] = 'LoTW';

$lang['general_word_details'] = 'Details';
$lang['general_word_qso_data'] = 'QSO Data';

$lang['general_edit_qso'] = 'Редактирай QSO';
$lang['general_mark_qsl_rx_bureau'] = 'Маркирайте QSL получена (Бюро)';
$lang['general_mark_qsl_rx_direct'] = 'Маркирайте QSL получена (Директно)';
$lang['general_mark_qsl_rx_electronic'] = 'Маркирайте получено QSL (електронно)';
$lang['general_mark_qsl_tx_bureau'] = 'Маркирайте QSL като изпратено (Бюро)';
$lang['general_mark_qsl_tx_direct'] = 'Маркирайте QSL като изпратено(Директно)';
$lang['general_mark_qsl_requested'] = 'Маркирайте QSL карта като поискана';
$lang['general_mark_qsl_requested_bureau'] = 'Маркирайте QSL карта като поискана (Бюро)';
$lang['general_mark_qsl_requested_direct'] = 'Маркирайте QSL карта като поискана(Директно)';
$lang['general_mark_qsl_not_required'] = 'Маркирайте QSL картата като неизискваща';

$lang['general_delete_qso'] = 'Изтрий QSO';
$lang['general_more_qso'] = 'More QSOs';

$lang['general_lookup_qrz'] = 'Lookup on QRZ.com';
$lang['general_lookup_hamqth'] = 'Lookup on HamQTH';

$lang['general_total_distance'] = 'Общо разстояние';

// PHP Upload Warning
$lang['gen_max_file_upload_size'] = 'Maximum file upload size is ';

// Cloudlog Terms
$lang['cloudlog_station_profile'] = 'Местоположение на станцията';

// ham radio terms
$lang['gen_hamradio_cq'] = "CQ";
$lang['gen_hamradio_qso'] = 'QSO';
$lang['gen_hamradio_station'] = 'Станция';

$lang['gen_hamradio_call'] = 'Инициал';
$lang['gen_hamradio_callsign'] = 'Инициал';
$lang['gen_hamradio_de'] = 'De';
$lang['gen_hamradio_dx'] = 'Dx';
$lang['gen_hamradio_mode'] = 'Режим';
$lang['gen_hamradio_rst_sent'] = 'Sent';
$lang['gen_hamradio_rst_rcvd'] = 'Recv\'d';
$lang['gen_hamradio_band'] = 'Обхват';
$lang['gen_hamradio_bandgroup'] = "Bandgroup";
$lang['gen_hamradio_band_rx'] = 'Обхват (RX)';
$lang['gen_hamradio_frequency'] = 'Честота';
$lang['gen_hamradio_frequency_rx'] = 'Честота (RX)';
$lang['gen_hamradio_radio'] = 'Радио';
$lang['gen_hamradio_rsts'] = 'RST (S)';
$lang['gen_hamradio_rstr'] = 'RST (R)';
$lang['gen_hamradio_refs'] = 'Refs';
$lang['gen_hamradio_myrefs'] = 'My Refs';
$lang['gen_hamradio_exchange_sent_short'] = 'Exch (S)';
$lang['gen_hamradio_exchange_rcvd_short'] = 'Exch (R)';
$lang['gen_hamradio_qsl'] = 'QSL';
$lang['gen_hamradio_qsltype'] = "QSL Type";
$lang['gen_hamradio_qslvia'] = 'QSL via';
$lang['gen_hamradio_qslmsg'] = 'QSL Msg';
$lang['gen_hamradio_locator'] = 'Локатор';
$lang['gen_hamradio_transmit_power'] = 'Мощност на предавателя (W)';
$lang['gen_hamradio_propagation_mode'] = 'Propagation Mode';

$lang['gen_hamradio_satellite_name'] = 'Име на сателита';
$lang['gen_hamradio_satellite_mode'] = 'Режим на сателита';

$lang['gen_hamradio_logbook'] = 'Дневник';

$lang['gen_hamradio_zones'] = 'Zones';
$lang['gen_hamradio_cq_zone'] = 'CQ зона';
$lang['gen_hamradio_itu_zone'] = 'ITU Zone';
$lang['gen_hamradio_dxcc'] = 'DXCC';
$lang['gen_hamradio_deleted_dxcc'] = 'Deleted DXCC';
$lang['gen_hamradio_continent'] = 'Continent';
$lang['gen_hamradio_usa_state'] = 'USA щат';
$lang['gen_hamradio_county_reference'] = 'USA окръг';
$lang['gen_hamradio_iota_reference'] = 'IOTA референция';
$lang['gen_hamradio_sota_reference'] = 'SOTA референция';
$lang['gen_hamradio_wwff_reference'] = 'WWFF референция';
$lang['gen_hamradio_pota_reference'] = 'POTA Reference';
$lang['gen_hamradio_dok'] = 'DOK';
$lang['gen_hamradio_state'] = 'State';
$lang['gen_hamradio_iota'] = 'IOTA';
$lang['gen_hamradio_sota'] = 'SOTA';
$lang['gen_hamradio_wwff'] = 'WWFF';
$lang['gen_hamradio_pota'] = 'POTA';
$lang['gen_hamradio_gridsquare'] = 'Gridsquare';
$lang['gen_hamradio_get_gridsquare'] = 'Get Gridsquare';
$lang['gen_hamradio_distance'] = 'Distance';
$lang['gen_hamradio_operator'] = 'Operator';

$lang['gen_hamradio_sig'] = 'Sig';
$lang['gen_hamradio_sig_info'] = 'Sig Info';

// Find your CQ/ITU Zone
$lang['gen_find_zone_cq_part1'] = "If you don't know your CQ Zone then ";
$lang['gen_find_zone_itu_part1'] = "If you don't know your ITU Zone then ";
$lang['gen_find_zone_part2'] = 'click here';
$lang['gen_find_zone_part3'] = ' to find it!';

// Dashboard Words
$lang['dashboard_you_have_had'] = 'Вие сте имали';
$lang['dashboard_qsos_today'] = 'QSO-та днес!';
$lang['dashboard_qso_breakdown'] = 'Разбивка на QSO-тата';
$lang['dashboard_countries_breakdown'] = 'Разбивка по държави';
$lang['gen_to_date'] = 'To date';

$lang['gen_from_date'] = 'От дата';

$lang['gen_this_qso_was_confirmed_on'] = 'Това QSO беше потвърдено на';

$lang['error_no_logbook_found'] = 'No logbooks were found. You need to define a logbook under Station Logbooks! Do it here:';

$lang['copy_to_clipboard'] = 'Copy to clipboard';

$lang['africa'] = 'Africa';
$lang['antarctica'] = 'Antarctica';
$lang['asia'] = 'Asia';
$lang['europe'] = 'Europe';
$lang['northamerica'] = 'North America';
$lang['oceania'] = 'Oceania';
$lang['southamerica'] = 'South America';

$lang['gen_band_selection'] = 'Band selection';
$lang['general_word_today'] = 'Today';

$lang['dashboard_php_version_warning'] = 'You need to upgrade your PHP version. Minimum version is 7.4. Your version is';
$lang['dashboard_country_files_warning'] = 'You need to update country files! Go <a href="'.site_url('update').'">here</a> to do it!';
$lang['dashboard_locations_warning'] = 'You have no station locations. Go <a href="'. site_url('station') . '">here</a> to create it!';
$lang['dashboard_logbooks_warning'] = 'You have no station logbook. Go <a href="'. site_url('logbooks') . '">here</a> to create it!';

==> 2.6.6.zip: cloudlog/application/language/bulgarian/general_words_lang.php <==
<?php

defined('BASEPATH') OR exit('Не е разрешен директен достъп до скрипта');

$lang['error_no_active_station_profile'] = 'Внимание: трябва да зададете местоположение на активната станция.';

$lang['notice_turn_the_radio_on'] = 'Днес не сте правили QSO; време е да включите радиото!';

$lang['general_word_important'] = 'Важно';
$lang['general_word_warning'] = 'Warning';
$lang['general_word_danger'] = 'DANGER';
$lang['general_word_maintenance'] = 'Maintenance';
$lang['general_word_info'] = 'Инфо';
$lang['general_word_choose_file'] = 'Изберете файл';
$lang['general_word_next'] = 'Next';
$lang['general_word_previous'] = 'Previous';
$lang['general_word_cancel'] = "Cancel";
$lang['general_word_ok'] = "OK";
$lang['general_word_attention'] = "Attention";
$lang['general_word_enabled'] = "Enabled";
$lang['general_word_disabled'] = "Disabled";
$lang['general_word_export'] = "Export";
$lang['general_word_import'] = "Import";
$lang['general_word_count'] = "Count";
$lang['general_word_filtering_on'] = "Filtering on";
$lang['general_word_not_display'] = "Not display";
$lang['general_word_icon'] = "Icon";
$lang['general_word_never'] = "Never";

$lang['general_word_date'] = 'Дата';
$lang['general_word_startdate'] = "Start Date";
$lang['general_word_enddate'] = "End Date";
$lang['general_word_time'] = 'Час';
$lang['general_word_time_on'] = 'Time on';
$lang['general_word_time_off'] = 'Time off';
$lang['general_word_datetime'] = 'Дата/Час';
$lang['general_word_none'] = 'Нито едно';
$lang['general_word_name'] = 'Име';
$lang['general_word_location'] = 'Местоположение';
$lang['general_word_comment'] = 'Коментар';
$lang['general_word_general'] = 'Общи';
$lang['general_word_satellite'] = 'Сателит';
$lang['general_word_satellite_short'] = 'Сат';
$lang['general_word_notes'] = 'Бележки';
$lang['general_word_country'] = 'Държава';
$lang['general_word_city'] = 'Град';

$lang['general_word_total'] = 'Общо';
$lang['general_word_year'] = 'Година';
$lang['general_word_month'] = 'Месец';
$lang['general_word_day'] = "Day";
$lang['general_word_days'] = "Days";

$lang['general_word_colors'] = "Colors";
$lang['general_word_light'] = "Light/Laser";
$lang['general_word_worked'] = 'Работени';
$lang['general_word_worked_not_confirmed'] = "Worked not confirmed";
$lang['general_word_not_worked'] = "Not worked";
$lang['general_word_confirmed'] = 'Потвърдени';
$lang['general_word_confirmation'] = "Confirmation";
$lang['general_word_needed'] = 'Необходими';

$lang['general_word_all'] = 'All';
$lang['general_word_no'] = 'Не';
$lang['general_word_yes'] = 'Да';
$lang['general_word_method'] = 'Метод';

$lang['general_word_sent'] = 'Изпратени';
$lang['general_word_received'] = 'Получени';
$lang['general_word_requested'] = 'Заявени';
$lang['general_word_queued'] = 'Queued';
$lang['general_word_table'] = "Table";
$lang['general_word_invalid_ignore'] = 'Invalid (Ignore)';
$lang['general_word_qslcard'] = 'QSL катичка';
$lang['general_word_qslcard_management'] = 'Управление на QSL';
$lang['general_word_qslcards'] = 'QSL картички';
$lang['general_word_qslcard_direct'] = 'Директено';
$lang['general_word_qslcard_bureau'] = 'Бюро';
$lang['general_word_qslcard_electronic'] = 'Electronic';
$lang['general_word_qslcard_manager'] = 'Manager';
$lang['general_word_qslcard_via'] = 'Чрез';
$lang['general_word_eqslcard'] = 'eQSL Card';
$lang['general_word_eqslcards'] = 'eQSL Cards';
$lang['general_word_lotw'] = 'Logbook of the World';
$lang['general_word_lotw_short'] = 'LoTW';

$lang['general_word_details'] = 'Details';
$lang['general_word_qso_data'] = 'QSO Data';

$lang['general_edit_qso'] = 'Редактирай QSO';
$lang['general_mark_qsl_rx_bureau'] = 'Маркирайте QSL получена (Бюро)';
$lang['general_mark_qsl_rx_direct'] = 'Маркирайте QSL получена (Директно)';
$lang['general_mark_qsl_rx_electronic'] = 'Маркирайте получено QSL (електронно)';
$lang['general_mark_qsl_tx_bureau'] = 'Маркирайте QSL като изпратено (Бюро)';
$lang['general_mark_qsl_tx_direct'] = 'Маркирайте QSL като изпратено(Директно)';
$lang['general_mark_qsl_requested'] = 'Маркирайте QSL карта като поискана';
$lang['general_mark_qsl_requested_bureau'] = 'Маркирайте QSL карта като поискана (Бюро)';
$lang['general_mark_qsl_requested_direct'] = 'Маркирайте QSL карта като поискана(Директно)';
$lang['general_mark_qsl_not_required'] = 'Маркирайте QSL картата като неизискваща';

$lang['general_delete_qso'] = 'Изтрий QSO';
$lang['general_more_qso'] = 'More QSOs';

$lang['general_lookup_qrz'] = 'Lookup on QRZ.com';
$lang['general_lookup_hamqth'] = 'Lookup on HamQTH';

$lang['general_total_distance'] = 'Общо разстояние';

// PHP Upload Warning
$lang['gen_max_file_upload_size'] = 'Maximum file upload size is ';

// Cloudlog Terms
$lang['cloudlog_station_profile'] = 'Местоположение на станцията';

// ham radio terms
$lang['gen_hamradio_cq'] = "CQ";
$lang['gen_hamradio_qso'] = 'QSO';
$lang['gen_hamradio_station'] = 'Станция';

$lang['gen_hamradio_call'] = 'Инициал';
$lang['gen_hamradio_callsign'] = 'Инициал';
$lang['gen_hamradio_prefix'] = "Prefix";
$lang['gen_hamradio_suffix'] = "Suffix";
$lang['gen_hamradio_de'] = 'De';
$lang['gen_hamradio_dx'] = 'Dx';
$lang['gen_hamradio_mode'] = 'Режим';
$lang['gen_hamradio_ant_az'] = 'Antenna Azimuth';
$lang['gen_hamradio_ant_el'] = 'Antenna Elevation';
$lang['gen_hamradio_rst_sent'] = 'Sent';
$lang['gen_hamradio_rst_rcvd'] = 'Recv\'d';
$lang['gen_hamradio_band'] = 'Обхват';
$lang['gen_hamradio_bandgroup'] = "Bandgroup";
$lang['gen_hamradio_band_rx'] = 'Обхват (RX)';
$lang['gen_hamradio_frequency'] = 'Честота';
$lang['gen_hamradio_frequency_rx'] = 'Честота (RX)';
$lang['gen_hamradio_radio'] = 'Радио';
$lang['gen_hamradio_rsts'] = 'RST (S)';
$lang['gen_hamradio_rstr'] = 'RST (R)';
$lang['gen_hamradio_refs'] = 'Refs';
$lang['gen_hamradio_myrefs'] = 'My Refs';
$lang['gen_hamradio_exchange_sent_short'] = 'Exch (S)';
$lang['gen_hamradio_exchange_rcvd_short'] = 'Exch (R)';
$lang['gen_hamradio_qsl'] = 'QSL';
$lang['gen_hamradio_qsltype'] = "QSL Type";
$lang['gen_hamradio_qslvia'] = 'QSL via';
$lang['gen_hamradio_qslmsg'] = 'QSL Msg';
$lang['gen_hamradio_locator'] = 'Локатор';
$lang['gen_hamradio_transmit_power'] = 'Мощност на предавателя (W)';
$lang['gen_hamradio_propagation_mode'] = 'Propagation Mode';

$lang['gen_hamradio_satellite_name'] = 'Име на сателита';
$lang['gen_hamradio_satellite_mode'] = 'Режим на сателита';

$lang['gen_hamradio_logbook'] = 'Дневник';
$lang['gen_hamradio_award'] = "Award";

$lang['gen_hamradio_zones'] = 'Zones';
$lang['gen_hamradio_cq_zone'] = 'CQ зона';
$lang['gen_hamradio_itu_zone'] = 'ITU Zone';
$lang['gen_hamradio_dxcc'] = 'DXCC';
$lang['gen_hamradio_deleted_dxcc'] = 'Deleted DXCC';
$lang['gen_hamradio_continent'] = 'Continent';
$lang['gen_hamradio_usa_state'] = 'USA щат';
$lang['gen_hamradio_county_reference'] = 'USA окръг';
$lang['gen_hamradio_iota_reference'] = 'IOTA референция';
$lang['gen_hamradio_sota_reference'] = 'SOTA референция';
$lang['gen_hamradio_wwff_reference'] = 'WWFF референция';
$lang['gen_hamradio_pota_reference'] = 'POTA Reference';
$lang['gen_hamradio_dok'] = 'DOK';
$lang['gen_hamradio_state'] = 'State';
$lang['gen_hamradio_iota'] = 'IOTA';
$lang['gen_hamradio_sota'] = 'SOTA';
$lang['gen_hamradio_wwff'] = 'WWFF';
$lang['gen_hamradio_pota'] = 'POTA';
$lang['gen_hamradio_gridsquare'] = 'Gridsquare';
$lang['gen_hamradio_get_gridsquare'] = 'Get Gridsquare';
$lang['gen_hamradio_gridsquare_show'] = "Show Locator";
$lang['gen_hamradio_latitude'] = "Latitude";
$lang['gen_hamradio_longitude'] = "Longitude";
$lang['gen_hamradio_bearing'] = "Bearing";
$lang['gen_hamradio_distance'] = 'Distance';
$lang['gen_hamradio_operator'] = 'Operator';

$lang['gen_hamradio_sig'] = 'Sig';
$lang['gen_hamradio_sig_info'] = 'Sig Info';

// Find your CQ/ITU Zone
$lang['gen_find_zone_cq_part1'] = "If you don't know your CQ Zone then";
$lang['gen_find_zone_itu_part1'] = "If you don't know your ITU Zone then";
$lang['gen_find_zone_part2'] = "click here";
$lang['gen_find_zone_part3'] = "to find it!";

// Dashboard Words
$lang['dashboard_you_have_had'] = 'Вие сте имали';
$lang['dashboard_qsos_today'] = 'QSO-та днес!';
$lang['dashboard_qso_breakdown'] = 'Разбивка на QSO-тата';
$lang['dashboard_countries_breakdown'] = 'Разбивка по държави';
$lang['gen_to_date'] = 'To date';

$lang['gen_from_date'] = 'От дата';

$lang['gen_this_qso_was_confirmed_on'] = 'Това QSO беше потвърдено на';

$lang['error_no_logbook_found'] = 'No logbooks were found. You need to define a logbook under Station Logbooks! Do it here:';

$lang['copy_to_clipboard'] = 'Copy to clipboard';

$lang['africa'] = 'Africa';
$lang['antarctica'] = 'Antarctica';
$lang['asia'] = 'Asia';
$lang['europe'] = 'Europe';
$lang['northamerica'] = 'North America';
$lang['oceania'] = 'Oceania';
$lang['southamerica'] = 'South America';

$lang['gen_band_selection'] = 'Band selection';
$lang['general_word_today'] = 'Today';

$lang['dashboard_php_version_warning'] = 'You need to upgrade your PHP version. Minimum version is 7.4. Your version is';
$lang['dashboard_country_files_warning'] = 'You need to update country files! Go <a href="'.site_url('update').'">here</a> to do it!';
$lang['dashboard_locations_warning'] = 'You have no station locations. Go <a href="'. site_url('station') . '">here</a> to create it!';
$lang['dashboard_logbooks_warning'] = 'You have no station logbook. Go <a href="'. site_url('logbooks') . '">here</a> to create it!';

$lang['hams_at_no_activations_found'] = 'No upcoming activations found. Please check back later.';

$lang['datatables_language'] = "en-GB";
